@@ -1,3 +1,12 @@
+#!/usr/bin/python
+# -*- coding: utf-8 -*-
+
+__author__ = "Timo Stollenwerk (timo@zmag.de)"
+__license__ = "GNU General Public License (GPL)"
+__revision__ = "$Rev$"
+__date__ = "$Date$"
+__URL__ = "$URL$"
+
 import sys
 import tempfile
 
